<?xml version="1.0" encoding="UTF-8"?>
<!--*********************************************************************************************************** 	
	created by: Laura Robinson
	contact: lrobinson@secstate.wa.gov
	create date: 2009-05-01
	notes: this file was written and tested with the SAXON 6.5.3 transformation processor and is meant to 
	tranform the input file (e.g. titleTbl.xml) to recreate the appropriate database table while comparing it 
	to the output from the batch.xml file. It recreates the table with color-coded backgrounds indicating possible 
	missing or mismatched data. 
	
	to do:
	1. need to comment
	2. perhaps cross check that all titles exist in reelTbl.xml
	***********************************************************************************************************-->	 
	
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:mods="http://www.loc.gov/mods/v3" xmlns:ndnp="http://www.loc.gov/ndnp" xmlns:od="urn:schemas-microsoft-com:officedata" version="1.0">
	<xsl:output method="html"/>
	<xsl:key name="lccnTest" match="ndnp:batch/ndnp:reel" use="substring-before(substring-after(., './'), '/')"/>
	<xsl:param name="batchFilePath"/>
	<xsl:variable name="batchFile" select="document($batchFilePath)"/>
	<xsl:template match="dataroot">
		<html>
			<body>
				<h1>Test: titleTbl</h1>
				<!-- use * rather than . because we are at the root element -->
				<h3>Batch: <xsl:value-of select="$batchFile/*/@name"/></h3>
				<h3>List of titles in batch (i.e. unique lccns from ndnp:reel elements):</h3>
				<ol>
					<xsl:for-each select="$batchFile/ndnp:batch/ndnp:reel[generate-id(.) = generate-id(key('lccnTest', substring-before(substring-after(., './'), '/'))[1])]">
						<li>
							<xsl:value-of select="substring-before(substring-after(., './'), '/')"/>
						</li>
					</xsl:for-each>
				</ol>
				<h3>titleTbl:</h3>
				<xsl:text>Note: Titles in red are missing from </xsl:text>
				<a>
					<xsl:attribute name="href">
						<xsl:value-of select="$batchFilePath"/>
					</xsl:attribute>
					<xsl:attribute name="target">
						<xsl:text>_blank</xsl:text>
					</xsl:attribute>					
					<xsl:value-of select="$batchFilePath"/>
				</a>
				<table border="1">
					<tr>
						<td>title</td>
						<td>paperLocation</td>
						<td>lccn</td>
					</tr>
					<xsl:apply-templates select="titleTbl"/>				
				</table>
					<xsl:element name="a">
						<xsl:attribute name="href">reelTbl_report.html</xsl:attribute>
						<xsl:text>reelTbl_report.html</xsl:text>
					</xsl:element><br/>
					<xsl:element name="a">
						<xsl:attribute name="href">issueTbl_report.html</xsl:attribute>
						<xsl:text>issueTbl_report.html</xsl:text>
					</xsl:element>					
			</body>
		</html>
	</xsl:template>
	<xsl:template match="titleTbl">
		<xsl:variable name="title" select="title"/>
		<xsl:variable name="lccn" select="lccn"/>
		<xsl:variable name="paperLocation" select="paperLocation"/>
		<tr>
			<xsl:for-each select="$batchFile">
				<xsl:variable name="keyMatch">
					<xsl:apply-templates select="key('lccnTest', $lccn)"/>
				</xsl:variable>
				<xsl:if test="$keyMatch = ''">
					<xsl:attribute name="bgcolor">
						<xsl:text>red</xsl:text>
					</xsl:attribute>
				</xsl:if>
				<td>
					<xsl:value-of select="$title"/>
				</td>
				<td>
					<xsl:value-of select="$paperLocation"/>
				</td>
				<td>
					<xsl:value-of select="$lccn"/>
				</td>
			</xsl:for-each>
		</tr>
	</xsl:template>
</xsl:stylesheet>